# Pyturbo Package

Author: Lijun Yu

Email: lijun@lj-y.com

A pipeline system for efficient execution.

## Demo program

See [demo.py](demo.py).

## Version History

See [version.md](docs/version.md).
